@@ -36,12 +36,12 @@ import org.joni.ast.EncloseNode;
 import org.joni.ast.Node;
 import org.joni.ast.QuantifierNode;
 import org.joni.ast.StringNode;
-import org.joni.constants.AnchorType;
-import org.joni.constants.EncloseType;
-import org.joni.constants.NodeType;
-import org.joni.constants.OPCode;
-import org.joni.constants.OPSize;
-import org.joni.constants.TargetInfo;
+import org.joni.constants.internal.AnchorType;
+import org.joni.constants.internal.EncloseType;
+import org.joni.constants.internal.NodeType;
+import org.joni.constants.internal.OPCode;
+import org.joni.constants.internal.OPSize;
+import org.joni.constants.internal.TargetInfo;
 
 final class ArrayCompiler extends Compiler {
     private int[]code;
