@@ -20,16 +20,19 @@
 package org.joni;
 
 import static org.joni.BitStatus.bsAt;
+import static org.joni.Config.USE_SUNDAY_QUICK_SEARCH;
 import static org.joni.Option.isCaptureGroup;
 import static org.joni.Option.isDontCaptureGroup;
 
+import java.util.Collections;
 import java.util.Iterator;
 
+import org.jcodings.CaseFoldCodeItem;
 import org.jcodings.Encoding;
 import org.jcodings.specific.ASCIIEncoding;
 import org.jcodings.specific.UTF8Encoding;
 import org.jcodings.util.BytesHash;
-import org.joni.constants.AnchorType;
+import org.joni.constants.internal.AnchorType;
 import org.joni.exception.ErrorMessages;
 import org.joni.exception.InternalException;
 import org.joni.exception.ValueException;
@@ -61,10 +64,11 @@ public final class Regex {
     Object userObject;
     final int caseFoldFlag;
 
-    BytesHash<NameEntry> nameTable;        // named entries
+    private BytesHash<NameEntry> nameTable; // named entries
 
     /* optimization info (string search, char-map and anchors) */
-    SearchAlgorithm searchAlgorithm;        /* optimize flag */
+    Search.Forward forward;                 /* optimize flag */
+    Search.Backward backward;
     int thresholdLength;                    /* search str-length for apply optimize */
     int anchor;                             /* BEGIN_BUF, BEGIN_POS, (SEMI_)END_BUF */
     int anchorDmin;                         /* (SEMI_)END_BUF anchor distance */
@@ -155,8 +159,16 @@ public final class Regex {
         return matcher(bytes, 0, bytes.length);
     }
 
+    public Matcher matcherNoRegion(byte[]bytes) {
+        return matcherNoRegion(bytes, 0, bytes.length);
+    }
+
     public Matcher matcher(byte[]bytes, int p, int end) {
-        return factory.create(this, bytes, p, end);
+        return factory.create(this, numMem == 0 ? null : new Region(numMem + 1), bytes, p, end);
+    }
+
+    public Matcher matcherNoRegion(byte[]bytes, int p, int end) {
+        return factory.create(this, null, bytes, p, end);
     }
 
     public int numberOfCaptures() {
@@ -175,20 +187,7 @@ public final class Regex {
         }
     }
 
-    String nameTableToString() {
-        StringBuilder sb = new StringBuilder();
-
-        if (nameTable != null) {
-            sb.append("name table\n");
-            for (NameEntry ne : nameTable) {
-                sb.append("  " + ne + "\n");
-            }
-            sb.append("\n");
-        }
-        return sb.toString();
-    }
-
-    NameEntry nameFind(byte[]name, int nameP, int nameEnd) {
+    private NameEntry nameFind(byte[]name, int nameP, int nameEnd) {
         if (nameTable != null) return nameTable.get(name, nameP, nameEnd);
         return null;
     }
@@ -207,10 +206,6 @@ public final class Regex {
         }
     }
 
-    public int numberOfNames() {
-        return nameTable == null ? 0 : nameTable.size();
-    }
-
     void nameAdd(byte[]name, int nameP, int nameEnd, int backRef, Syntax syntax) {
         if (nameEnd - nameP <= 0) throw new ValueException(ErrorMessages.EMPTY_GROUP_NAME);
 
@@ -256,8 +251,25 @@ public final class Regex {
         }
     }
 
+    String nameTableToString() {
+        StringBuilder sb = new StringBuilder();
+
+        if (nameTable != null) {
+            sb.append("name table\n");
+            for (NameEntry ne : nameTable) {
+                sb.append("  " + ne + "\n");
+            }
+            sb.append("\n");
+        }
+        return sb.toString();
+    }
+
     public Iterator<NameEntry> namedBackrefIterator() {
-        return nameTable.iterator();
+        return nameTable == null ? Collections.<NameEntry>emptyIterator() : nameTable.iterator();
+    }
+
+    public int numberOfNames() {
+        return nameTable == null ? 0 : nameTable.size();
     }
 
     public boolean noNameGroupIsActive(Syntax syntax) {
@@ -270,49 +282,95 @@ public final class Regex {
     }
 
     /* set skip map for Boyer-Moor search */
-    void setupBMSkipMap() {
+    boolean setupBMSkipMap(boolean ignoreCase) {
         byte[]bytes = exact;
-        int p = exactP;
+        int s = exactP;
         int end = exactEnd;
-        int len = end - p;
+        int len = end - s;
+        int clen;
+        CaseFoldCodeItem[]items = CaseFoldCodeItem.EMPTY_FOLD_CODES;
+        byte[]buf = new byte[Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM * Config.ENC_MBC_CASE_FOLD_MAXLEN];
 
-        if (len < Config.CHAR_TABLE_SIZE) {
-            // map/skip
-            if (map == null) map = new byte[Config.CHAR_TABLE_SIZE];
+        final int ilen = USE_SUNDAY_QUICK_SEARCH ? len : len - 1;
+        if (Config.USE_BYTE_MAP || len < Config.CHAR_TABLE_SIZE) {
+            if (map == null) map = new byte[Config.CHAR_TABLE_SIZE]; // map/skip
+            for (int i = 0; i < Config.CHAR_TABLE_SIZE; i++) map[i] = (byte)(USE_SUNDAY_QUICK_SEARCH ? len + 1 : len);
 
-            for (int i=0; i<Config.CHAR_TABLE_SIZE; i++) map[i] = (byte)len;
-            for (int i=0; i<len-1; i++) map[bytes[p + i] & 0xff] = (byte)(len - 1 -i); // oxff ??
+            for (int i = 0; i < ilen; i += clen) {
+                if (ignoreCase) items = enc.caseFoldCodesByString(caseFoldFlag, bytes, s + i, end);
+                clen = setupBMSkipMapCheck(bytes, s + i, end, items, buf);
+                if (clen == 0) return true;
+
+                for (int j = 0; j < clen; j++) {
+                    map[bytes[s + i + j] & 0xff] = (byte)(ilen - i - j);
+                    for (int k = 0; k < items.length; k++) {
+                        map[buf[k * Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM + j] & 0xff] = (byte)(ilen - i - j);
+                    }
+                }
+            }
         } else {
             if (intMap == null) intMap = new int[Config.CHAR_TABLE_SIZE];
+            for (int i = 0; i < Config.CHAR_TABLE_SIZE; i++) intMap[i] = (USE_SUNDAY_QUICK_SEARCH ? len + 1 : len);
 
-            for (int i=0; i<len-1; i++) intMap[bytes[p + i] & 0xff] = len - 1 - i; // oxff ??
+            for (int i = 0; i < ilen; i += clen) {
+                if (ignoreCase) items = enc.caseFoldCodesByString(caseFoldFlag, bytes, s + i, end);
+                clen = setupBMSkipMapCheck(bytes, s + i, end, items, buf);
+                if (clen == 0) return true;
+
+                for (int j = 0; j < clen; j++) {
+                    intMap[bytes[s + i + j] & 0xff] = ilen - i - j;
+                    for (int k = 0; k < items.length; k++) {
+                        intMap[buf[k * Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM + j] & 0xff] = ilen - i - j;
+                    }
+                }
+            }
         }
+        return false;
     }
 
-    void setExactInfo(OptExactInfo e) {
+    private int setupBMSkipMapCheck(byte[]bytes, int p, int end, CaseFoldCodeItem[]items, byte[]buf) {
+        int clen = enc.length(bytes, p, end);
+        if (p + clen > end) clen = end - p;
+        for (int j = 0; j < items.length; j++) {
+            if (items[j].code.length != 1 || items[j].byteLen != clen) return 0;
+            int flen = enc.codeToMbc(items[j].code[0], buf, j * Config.ENC_GET_CASE_FOLD_CODES_MAX_NUM);
+            if (flen != clen) return 0;
+        }
+        return clen;
+    }
+
+    void setOptimizeExactInfo(OptExactInfo e) {
         if (e.length == 0) return;
 
         // shall we copy that ?
         exact = e.bytes;
         exactP = 0;
         exactEnd = e.length;
+        boolean allowReverse = enc.isReverseMatchAllowed(exact, exactP, exactEnd);
 
         if (e.ignoreCase > 0) {
-            // encodings won't return toLowerTable for case insensitive search if it's not safe to use it directly
-            searchAlgorithm = enc.toLowerCaseTable() != null ? SearchAlgorithm.SLOW_IC_SB : SearchAlgorithm.SLOW_IC;
-        } else {
-            boolean allowReverse = enc.isReverseMatchAllowed(exact, exactP, exactEnd);
-
             if (e.length >= 3 || (e.length >= 2 && allowReverse)) {
-                setupBMSkipMap();
-                if (allowReverse) {
-                    searchAlgorithm = SearchAlgorithm.BM;
+                forward = enc.toLowerCaseTable() != null ? Search.SLOW_IC_SB_FORWARD : Search.SLOW_IC_FORWARD;
+//                if (!setupBMSkipMap(true)) {
+//                    forward = allowReverse ? Search.BM_IC_FORWARD : Search.BM_NOT_REV_IC_FORWARD;
+//                } else {
+//                    forward = enc.toLowerCaseTable() != null ? Search.SLOW_IC_SB_FORWARD : Search.SLOW_IC_FORWARD;
+//                }
+            } else {
+                forward = enc.toLowerCaseTable() != null ? Search.SLOW_IC_SB_FORWARD : Search.SLOW_IC_FORWARD;
+            }
+            backward = enc.toLowerCaseTable() != null ? Search.SLOW_IC_SB_BACKWARD : Search.SLOW_IC_BACKWARD;
+        } else {
+            if (e.length >= 3 || (e.length >= 2 && allowReverse)) {
+                if (!setupBMSkipMap(false)) {
+                    forward = allowReverse ? Search.BM_FORWARD : Search.BM_NOT_REV_FORWARD;
                 } else {
-                    searchAlgorithm = SearchAlgorithm.BM_NOT_REV;
+                    forward = enc.isSingleByte() ? Search.SLOW_SB_FORWARD : Search.SLOW_FORWARD;
                 }
             } else {
-                searchAlgorithm = enc.isSingleByte() ? SearchAlgorithm.SLOW_SB : SearchAlgorithm.SLOW;
+                forward = enc.isSingleByte() ? Search.SLOW_SB_FORWARD : Search.SLOW_FORWARD;
             }
+            backward = enc.isSingleByte() ? Search.SLOW_SB_BACKWARD : Search.SLOW_BACKWARD;
         }
 
         dMin = e.mmd.min;
@@ -326,7 +384,14 @@ public final class Regex {
     void setOptimizeMapInfo(OptMapInfo m) {
         map = m.map;
 
-        searchAlgorithm = enc.isSingleByte() ? SearchAlgorithm.MAP_SB : SearchAlgorithm.MAP;
+        if (enc.isSingleByte()) {
+            forward = Search.MAP_SB_FORWARD;
+            backward = Search.MAP_SB_BACKWARD;
+        } else {
+            forward = Search.MAP_FORWARD;
+            backward = Search.MAP_BACKWARD;
+        }
+
         dMin = m.mmd.min;
         dMax = m.mmd.max;
 
@@ -341,7 +406,8 @@ public final class Regex {
     }
 
     void clearOptimizeInfo() {
-        searchAlgorithm = SearchAlgorithm.NONE;
+        forward = null;
+        backward = null;
         anchor = 0;
         anchorDmax = 0;
         anchorDmin = 0;
@@ -353,7 +419,7 @@ public final class Regex {
 
     public String optimizeInfoToString() {
         String s = "";
-        s += "optimize: " + searchAlgorithm.getName() + "\n";
+        s += "optimize: " + (forward != null ? forward.getName() : "NONE") + "\n";
         s += "  anchor:     " + OptAnchorInfo.anchorToString(anchor);
 
         if ((anchor & AnchorType.END_BUF_MASK) != 0) {
@@ -362,7 +428,7 @@ public final class Regex {
 
         s += "\n";
 
-        if (searchAlgorithm != SearchAlgorithm.NONE) {
+        if (forward != null) {
             s += "  sub anchor: " + OptAnchorInfo.anchorToString(subAnchor) + "\n";
         }
 
@@ -371,7 +437,7 @@ public final class Regex {
 
         if (exact != null) {
             s += "exact: [" + new String(exact, exactP, exactEnd - exactP) + "]: length: " + (exactEnd - exactP) + "\n";
-        } else if (searchAlgorithm == SearchAlgorithm.MAP || searchAlgorithm == SearchAlgorithm.MAP_SB) {
+        } else if (forward == Search.MAP_FORWARD || forward == Search.MAP_SB_FORWARD) {
             int n=0;
             for (int i=0; i<Config.CHAR_TABLE_SIZE; i++) if (map[i] != 0) n++;
 
